@@ -14,27 +14,42 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-set -e -o pipefail
+
+set -e -u -o pipefail
 
 _testlib_this="${BASH_SOURCE[0]}"
 _testlib_dir="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
+
+: "${COMPOSE_DIR:=$_testlib_dir}"
 COMPOSE_ENV_NAME=$(basename "$COMPOSE_DIR")
 RESULT_DIR=${RESULT_DIR:-"$COMPOSE_DIR/result"}
-RESULT_DIR_INSIDE="/tmp/smoketest/$(basename "$COMPOSE_ENV_NAME")/result"
-
-OM_HA_PARAM=""
-if [[ -n "${OM_SERVICE_ID}" ]] && [[ "${OM_SERVICE_ID}" != "om" ]]; then
-  OM_HA_PARAM="--om-service-id=${OM_SERVICE_ID}"
-fi
 
 source ${_testlib_dir}/compose_v2_compatibility.sh
 source "${_testlib_dir}/../smoketest/testlib.sh"
 
 : ${OZONE_COMPOSE_RUNNING:=false}
+: "${OZONE_VOLUME_OWNER:=}"
+: ${SECURITY_ENABLED:=false}
 : ${SCM:=scm}
+: ${SKIP_APACHE_VERIFY_DOWNLOAD:=${CI:-false}}
 
-# version is used in bucket name, which does not allow uppercase
-export OZONE_CURRENT_VERSION="$(echo "2.0.0" | sed -e 's/-SNAPSHOT//' | tr '[:upper:]' '[:lower:]')"
+# Check if running from output of Maven build or from source
+_is_build() {
+  local file=""
+  # Variable is replaced by Maven at build time,
+  # so if it empty, we are running from source, if non-empty, then running in build output (target)
+  [[ -n "/Users/leechungen/ozone-2.1/hadoop-ozone/dist/pom.xml" ]]
+}
+
+# Avoid `bad substitution` error
+if _is_build; then
+  # version is used in bucket name, which does not allow uppercase
+  # variable is replaced by Maven at build time
+  OZONE_CURRENT_VERSION="$(echo "2.1.0" | sed -e 's/-SNAPSHOT//' | tr '[:upper:]' '[:lower:]')"
+else
+  OZONE_CURRENT_VERSION=src
+fi
+export OZONE_CURRENT_VERSION
 
 # create temp directory for test data; only once, even if testlib.sh is sourced again
 if [[ -z "${TEST_DATA_DIR:-}" ]] && [[ "${KEEP_RUNNING:-false}" == "false" ]]; then
@@ -71,7 +86,7 @@ all_tests_in_immediate_child_dirs() {
 ## @description Find all test*.sh scripts in immediate child dirs,
 ## @description applying OZONE_ACCEPTANCE_SUITE or OZONE_TEST_SELECTOR filter.
 find_tests(){
-  if [[ -n "${OZONE_ACCEPTANCE_SUITE}" ]]; then
+  if [[ -n "${OZONE_ACCEPTANCE_SUITE:-}" ]]; then
     tests=$(all_tests_in_immediate_child_dirs | xargs grep -l "^#suite:${OZONE_ACCEPTANCE_SUITE}$" || echo "")
 
      # 'misc' is default suite, add untagged tests, too
@@ -86,7 +101,7 @@ find_tests(){
       echo "No tests found for suite ${OZONE_ACCEPTANCE_SUITE}"
       exit 1
     fi
-  elif [[ -n "${OZONE_TEST_SELECTOR}" ]]; then
+  elif [[ -n "${OZONE_TEST_SELECTOR:-}" ]]; then
     tests=$(all_tests_in_immediate_child_dirs | grep "${OZONE_TEST_SELECTOR}" || echo "")
 
     if [[ -z "${tests}" ]]; then
@@ -215,22 +230,28 @@ execute_robot_test(){
     fi
   done
 
-  SMOKETEST_DIR_INSIDE="${OZONE_DIR:-/opt/hadoop}/smoketest"
+  : ${OZONE_DIR:=/opt/hadoop}
+  SMOKETEST_DIR_INSIDE="$OZONE_DIR/smoketest"
 
+  RESULT_DIR_INSIDE="/tmp/smoketest/$COMPOSE_ENV_NAME/result"
   OUTPUT_PATH="$RESULT_DIR_INSIDE/${OUTPUT_FILE}"
 
+  OM_HA_PARAM=""
+  if [[ -n "${OM_SERVICE_ID:-}" ]] && [[ "${OM_SERVICE_ID}" != "om" ]]; then
+    OM_HA_PARAM="--om-service-id=${OM_SERVICE_ID}"
+  fi
+
   set +e
 
   # shellcheck disable=SC2068
   docker-compose exec -T "$CONTAINER" mkdir -p "$RESULT_DIR_INSIDE" \
     && docker-compose exec -T "$CONTAINER" robot \
-      -v ENCRYPTION_KEY:"${OZONE_BUCKET_KEY_NAME}" \
+      -v ENCRYPTION_KEY:"${OZONE_BUCKET_KEY_NAME:-}" \
       -v OM_HA_PARAM:"${OM_HA_PARAM}" \
       -v OM_SERVICE_ID:"${OM_SERVICE_ID:-om}" \
       -v OZONE_DIR:"${OZONE_DIR}" \
-      -v SECURITY_ENABLED:"${SECURITY_ENABLED}" \
       -v SCM:"${SCM}" \
-      ${ARGUMENTS[@]} --log NONE --report NONE "${OZONE_ROBOT_OPTS[@]}" --output "$OUTPUT_PATH" \
+      ${ARGUMENTS[@]} --log NONE --report NONE --output "$OUTPUT_PATH" \
       "$SMOKETEST_DIR_INSIDE/$TEST"
   local -i rc=$?
 
@@ -248,13 +269,16 @@ execute_robot_test(){
 
 ## @description Replace OM node order in config
 reorder_om_nodes() {
-  local c pid procname new_order
+  local c new_order
   local new_order="$1"
 
   if [[ -n "${new_order}" ]] && [[ "${new_order}" != "om1,om2,om3" ]]; then
-    for c in $(docker-compose ps | cut -f1 -d' ' | grep -e datanode -e recon -e s3g -e scm); do
-      docker exec "${c}" sed -i -e "s/om1,om2,om3/${new_order}/" /etc/hadoop/ozone-site.xml
-      echo "Replaced OM order with ${new_order} in ${c}"
+    for c in $(docker-compose ps | cut -f1 -d' ' | grep -v -e '^NAME$' -e '^om'); do
+      docker exec "${c}" bash -c \
+        "if [[ -f /etc/hadoop/ozone-site.xml ]]; then \
+          sed -i -e 's/om1,om2,om3/${new_order}/' /etc/hadoop/ozone-site.xml; \
+          echo 'Replaced OM order with ${new_order} in ${c}'; \
+        fi"
     done
   fi
 }
@@ -266,7 +290,7 @@ create_stack_dumps() {
     while read -r pid procname; do
       echo "jstack $pid > ${RESULT_DIR}/${c}_${procname}.stack"
       docker exec "${c}" bash -c "jstack $pid" > "${RESULT_DIR}/${c}_${procname}.stack"
-    done < <(docker exec "${c}" sh -c "jps | grep -v Jps" || true)
+    done < <(docker exec "${c}" bash -c "jps | grep -v Jps" || true)
   done
 }
 
@@ -319,7 +343,7 @@ create_containers() {
 }
 
 get_output_name() {
-  if [[ -n "${OUTPUT_NAME}" ]]; then
+  if [[ -n "${OUTPUT_NAME:-}" ]]; then
     echo "${OUTPUT_NAME}-"
   fi
 }
@@ -504,13 +528,27 @@ run_test_scripts() {
   return ${ret}
 }
 
+## @description Create the directory tree required for persisting data between
+##   compose cluster restarts
+create_data_dirs() {
+  if [[ -z "${OZONE_VOLUME}" ]]; then
+    return 1
+  fi
+
+  rm -fr "${OZONE_VOLUME}" 2> /dev/null || sudo rm -fr "${OZONE_VOLUME}"
+  for d in "$@"; do
+    mkdir -p "${OZONE_VOLUME}"/"${d}"
+  done
+  fix_data_dir_permissions
+}
+
 ## @description Make `OZONE_VOLUME_OWNER` the owner of the `OZONE_VOLUME`
 ##   directory tree (required in Github Actions runner environment)
 fix_data_dir_permissions() {
   if [[ -n "${OZONE_VOLUME}" ]] && [[ -n "${OZONE_VOLUME_OWNER}" ]]; then
     current_user=$(whoami)
     if [[ "${OZONE_VOLUME_OWNER}" != "${current_user}" ]]; then
-      chown -R "${OZONE_VOLUME_OWNER}" "${OZONE_VOLUME}" \
+      chown -R "${OZONE_VOLUME_OWNER}" "${OZONE_VOLUME}" 2> /dev/null \
         || sudo chown -R "${OZONE_VOLUME_OWNER}" "${OZONE_VOLUME}"
     fi
   fi
@@ -586,3 +624,30 @@ wait_for_root_certificate(){
   echo "Timed out waiting on $count root certificates. Current timestamp " $(date +"%T")
   return 1
 }
+
+download_if_not_exists() {
+  local url="$1"
+  local f="$2"
+
+  if [[ -e "${f}" ]]; then
+    echo "${f} already downloaded"
+  else
+    echo "Downloading ${f} from ${url}"
+    curl --fail --location --output "${f}" --show-error --silent "${url}" || rm -fv "${f}"
+  fi
+}
+
+download_and_verify_apache_release() {
+  local remote_path="$1"
+
+  local f="$(basename "${remote_path}")"
+  local base_url="${APACHE_MIRROR_URL:-https://www.apache.org/dyn/closer.lua?action=download&filename=}"
+  local checksum_base_url="${APACHE_OFFICIAL_URL:-https://downloads.apache.org/}"
+  local download_dir="${DOWNLOAD_DIR:-/tmp}"
+
+  download_if_not_exists "${base_url}${remote_path}" "${download_dir}/${f}"
+  if [[ "${SKIP_APACHE_VERIFY_DOWNLOAD}" != "true" ]]; then
+    download_if_not_exists "${checksum_base_url}${remote_path}.asc"  "${download_dir}/${f}.asc"
+    gpg --verify "${download_dir}/${f}.asc" "${download_dir}/${f}" || exit 1
+  fi
+}
